#!/bin/bash
#
# 08/10/2013 Updated to add detection for tomcat verstion (RA)
# 14/02/2014 Updated to copy cache.xml from old location to new config dir (RA)

source /backups/patch/settings.sh

cleanup() {
 cd $PATCHBASE
 rm -rf *
 rm -rf /tmp/userportal
 echo; echo "Clean up done..."
}

initialise() {
 if test -f /etc/rc.d/init.d/tomcat5; then
  TOMCAT=tomcat5; fi
 if test -f /etc/rc.d/init.d/tomcat; then
  TOMCAT=tomcat; fi
 if test ! $TOMCAT; then
  echo "Unable to detect the version of tomcat installed."
  echo "Exiting..."
  exit; fi
}

appliance_type() {
 PINSAFE_TYPE=`grep PINSAFE_TYPE $PINSAFE_CONF|cut -d\= -f2`

 if test ! $PINSAFE_TYPE; then
  stnd_err "Appliance type is not correctly configured."; fi
 if test "$PINSAFE_TYPE" = "Single"; then
  PINSAFE_TYPE="Single "; fi
}

check_drbd() {
 DRBD_TYPE=`grep DRBD $PINSAFE_CONF|cut -d\= -f2`
 
 if test "$DRBD_TYPE" = "yes"; then
   USER_PORTAL=$USER_PORTAL_DRBD
 fi
}

heading() {
 clear
 echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}                                             ${inv}$PINSAFE_TYPE${nor}"
 echo
 echo $1
 echo
}

execute_if_false() {
 echo
 echo -n "${2:-'Are you sure'}? (Yes/No): "
 read yn
 check_if_false "$1" "$yn"
}

execute_if_true() {
 echo
 echo -n "${2:-'Are you sure'}? (Yes/No): "
 read yn
 check_if_true "$1" "$yn"
}

check_if_false() {
 if test ! $2; then
  $1
  else
 if test ! $2 = "Yes" && test ! $2 = "yes" && test ! $2 = "y" && test ! $2 = "Y" ; then
  $1; fi
  fi
}

check_if_true() {
 if test ! $2; then
  $1
  else
 if test $2 = "Yes" || test $2 = "yes" || test $2 = "y" || test $2 = "Y" ; then
  $1; fi
  fi
}

check_running() {
 if test "`ps -eaf|grep $2|egrep -v "UID|grep|mysqld_safe|alert.d" 2>/dev/null`"; then
  if test ! -f $LOCK/$1; then
   touch $LOCK/$1; fi
 else
  if test -f $LOCK/$1; then
   rm -f $LOCK/$1; fi
 fi

 if test -f $LOCK/$1; then
  value="Running"
 else
  value="Stopped"
 fi
}

show_dots() {
 i=0
 while test $i -lt $1; do
  echo -n "."
  sleep 1 
  ((i = i + 1))
 done
}

service_sands_tomcat() {
 nohup service $TOMCAT $1 > /dev/null 2>&1 &
 echo -n "Tomcat: $1"
 show_dots 4
 echo
}

service_sands() {
 service $1 $2
}

warning() {
 heading "Upgrading Swivel User Portal"
 echo "Continuing will apply patch ${inv}Swivel User Portal $PATCH_VER${nor}."
 echo "The Swivel solution cannot be used whilst upgrading."
 echo
 execute_if_false exit
}

appliance_version() {
 APPLIANCE_VERS=`grep ^APPLIANCE_VERS= $PINSAFE_CONF|cut -d\= -f2`
 APPLIANCE_VERS=$(echo $APPLIANCE_VERS|awk -F\. '{print $1$2$3}')
 APPLIANCE_REQUIRED=$(echo $APPLIANCE_REQUIRED|awk -F\. '{print $1$2$3}')

 if test $APPLIANCE_VERS && test $APPLIANCE_REQUIRED; then
  if test $APPLIANCE_VERS -lt $APPLIANCE_REQUIRED; then
   echo "The appliance requires patching before Swivel Proxy can be updated"
   echo; read -p "Press Return to exit" yn
   exit; fi
 else
  echo "Unable to determine appliance version"
  echo; read -p "Press Return to exit" yn
  exit
 fi
}

configure_image_url() {
	echo
	echo "Please enter the server details for displaying TURing images:"
	echo
	echo "Use https (Y/N)?"
	read yn
	if test ! $yn = "Yes" && test ! $yn = "yes" && test ! $yn = "y" && test ! $yn = "Y" ; then
		swivel_https='false'
	else
		swivel_https='true'
	fi
	echo
	echo "Please enter the server name or IP address:"
	read swivel_server
	echo
	echo "Please enter the server port (e.g. 8080 or 8443):"
	read swivel_port
	echo
	echo "Please enter the server context (e.g. pinsafe or proxy):"
	read swivel_context
	
	# OK, we've got all the values, let's insert them into the properties file.
	# We're assuming the original properties file is passed as the function input
	# and we will echo the modified properties file.
	
	sed -e "s/imagessl=.*/imagessl=${swivel_https}/" -e "s/imageserver=.*/imageserver=${swivel_server}/" -e "s/imagecontext=.*/imagecontext=${swivel_context}/" -e"s/imageport=.*/imageport=${swivel_port}/" $1 > $2
}

archive_and_remove() {
 if test -z $1; then
   echo "No application specified"; return; fi
 
 echo; echo "Creating backup of $1 to /tmp"
 if test -d $TOMCAT_PATH/webapps2/$1; then
  cp -rp $TOMCAT_PATH/webapps2/$1 /tmp; 
 echo; echo "Removing old application, please wait..."
 rm -f $TOMCAT_PATH/webapps2/$1.war
 sleep 10
 if test -d $TOMCAT_PATH/webapps2/$1; then
   sleep 10
   if test -d $TOMCAT_PATH/webapps2/$1; then
    rm -rf $TOMCAT_PATH/webapps2/$1;
	fi 
 fi
  
 fi
}

check_remove_app() {
	if test -d $TOMCAT_PATH/webapps2/$1; then
	  execute_if_true "archive_and_remove $1" "Remove $1 application"
	fi
}

remove_old_apps() {
	check_remove_app 'resetpin'
	check_remove_app 'changepin'
}

install_user_portal() {
 check_running $TOMCAT tomcat
 if test $value = "Running"; then
  echo "Stopping Tomcat and Swivel service"
  service_sands $TOMCAT stop
 fi
 
 echo "Creating backup of original Swivel User Portal to /tmp"
 if test -d $TOMCAT_PATH/webapps2/userportal; then
  cp -rp $TOMCAT_PATH/webapps2/userportal /tmp; fi

 echo "Starting Tomcat and Swivel service"
 service_sands_tomcat start

 echo; echo "Removing old user portal instance, please wait..."
 rm -f $TOMCAT_PATH/webapps2/userportal.war
 sleep 10
 if test -d $TOMCAT_PATH/webapps2/userportal; then
   sleep 10
   if test -d $TOMCAT_PATH/webapps2/userportal; then
    rm -rf $TOMCAT_PATH/webapps2/userportal; fi 
 fi

 echo; echo "Deploying new Swivel User Portal software"
 cp $PATCHBASE/userportal.war $TOMCAT_PATH/webapps2 

 sleep 10
 if test ! -d $TOMCAT_PATH/webapps2/userportal; then
   sleep 10
   if test ! -d $TOMCAT_PATH/webapps2/userportal; then
     sleep 10
     if test ! -d $TOMCAT_PATH/webapps2/userportal; then
	   # Give up!
	   echo "Failed to deploy user portal"
	 fi
   fi
 fi
 if test -d $TOMCAT_PATH/webapps2/userportal; then
   echo "Upgrade complete"
 fi
}

appliance_type
heading "Upgrading Swivel User Portal"
initialise
appliance_version
check_drbd
warning
SETPROPS=1
if test -f $USER_PORTAL/settings.properties; then
	SETPROPS=0
else
  if test -f $TOMCAT_PATH/webapps2/userportal/WEB-INF/classes/settings.properties; then
    if test ! -d $USER_PORTAL; then
      mkdir $USER_PORTAL
    fi
    cp $TOMCAT_PATH/webapps2/userportal/WEB-INF/classes/settings.properties $USER_PORTAL/.
	SETPROPS=0
  fi
fi
install_user_portal
if test -f $TOMCAT_PATH/webapps2/userportal/WEB-INF/classes/settings.properties && test $SETPROPS = 1; then
  echo "Preparing to configure portal..."
  service_sands_tomcat stop
  if test ! -d $USER_PORTAL; then
    mkdir $USER_PORTAL
  fi
  configure_image_url $TOMCAT_PATH/webapps2/userportal/WEB-INF/classes/settings.properties $USER_PORTAL/settings.properties
  service_sands_tomcat start 
fi
remove_old_apps
cleanup
echo; read -p "Press Return to continue" yn
